ErrorKind

Enum ErrorKind 

pub enum ErrorKind {
Show 22 variants MessageNotFound, UnexpectedBehavior, Unsupported, Io(Error), Imap(Error), Pop(Error), Smtp(Error), Tls(Error), Maildir(MaildirError), MailEntry(MailEntryError), ParseTime(ParseError), ParseInt(ParseIntError), ParseAddress, InvalidLoginConfig, ParseMessage(MailParseError), InvalidMessage, MailServer, SerializeJSON, ConfigNotFound, ParseEmailAddress(ParsingError), MailBoxNotFound, NoClientAvailable,
}

Variants



MessageNotFound



UnexpectedBehavior

The server responded with some unexpected data.



Unsupported

The requested feature/function is unsupported for this client type.



Io(Error)



Imap(Error)

An error from the Imap server.



Pop(Error)

An error from the Pop server.



Smtp(Error)



Tls(Error)



Maildir(MaildirError)



MailEntry(MailEntryError)



ParseTime(ParseError)

Failed to parse a date/time from the server.



ParseInt(ParseIntError)



ParseAddress

Failed to parse a socket address which is used to connect to the remote mail server



InvalidLoginConfig

Failed to parse provided login config.



ParseMessage(MailParseError)

Failed to parse mail message.



InvalidMessage



MailServer

Error from the remote mail server.



SerializeJSON

Failed to serialize the given data to JSON.



ConfigNotFound

Could not detect a config from the given email address.



ParseEmailAddress(ParsingError)



MailBoxNotFound



NoClientAvailable